############################################################
###  Module Name: Defaults.pm
###       Author: Darryl Priest
###         Date: Fall 2003
###  Description: This module contains subroutines that will
###               return 'hard-coded' default values and do
###               common tasks in a standard way.
############################################################
package Defaults;

require Exporter;

$VERSION = 0.01;
@ISA = qw(Exporter);
@EXPORT = qw(
	     default_db_connect
	    );

############################################################
### SubRoutine: default_db_connect
### This subroutine will connect to the passed database in
### the standard way. If an Informix server name is also
### passed it will attempt to connect to the database on
### that server, otherwise it will attempt a shared memory
### connection first, if that fails it will attempt a tcp
### connection on the same server. If successful the database
### handle will be returned. Defaults will be set as follows:
### AutoCommit On
### ChopBlanks On
### RaiseError On
### PrintError On
### If database is logged, lock mode will be set to wait.
### If database is ansi, isolation will be set to dirty read.
############################################################
sub default_db_connect {

my ($DB, $Server) = @_;

my ($dbh);
if ( defined $Server and length($Server) > 1 ) {
   $dbh = DBI->connect("DBI:Informix:${DB}\@${Server}");
   }
 else {
   $dbh = DBI->connect("DBI:Informix:${DB}", undef, undef, { PrintError => 0, RaiseError => 0 });
   if ( ! defined $dbh ) {
      $Server = default_informix_tcp();
      $dbh = DBI->connect("DBI:Informix:${DB}\@${Server}");
   }
}

if ( defined $dbh ) {
   $dbh->{AutoCommit} = 1;
   $dbh->{ChopBlanks} = 1;
   $dbh->{PrintError} = 1;
   $dbh->{RaiseError} = 1;
   if ( $dbh->{ix_LoggedDatabase} )   { $dbh->do("set lock mode to wait;"); }
   if ( $dbh->{ix_ModeAnsiDatabase} ) { $dbh->do("set isolation to dirty read;"); }
   return $dbh;
   }
 else {
   die "$DB Database Open Error, Error: $DBI::errstr";
}
} ### End Of SubRoutine default_pmdata_connect

1;
